@@ -23,3 +23,29 @@ BEGIN {
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+Data::Localze::Log - Internal Logging Facilities
+
+=head1 SYNOPSIS
+
+Private use only. Provides all of the Log::Minimal functions
+
+=head1 FUNCTIONS
+
+=head2 critf
+=head2 critff
+=head2 croakf
+=head2 croakff
+=head2 ddf
+=head2 debugf
+=head2 debugff
+=head2 infof
+=head2 infoff
+=head2 warnf
+=head2 warnff
+
+=cut
